@@ -6,7 +6,7 @@
  * Date        : 2009-05-28
  * Description : database statistics dialog
  *
- * Copyright (C) 2009-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,7 +44,7 @@ class DBStatDlg : public InfoDlg
 {
 public:
 
-    DBStatDlg(QWidget* parent);
+    DBStatDlg(QWidget* const parent);
     ~DBStatDlg();
 
 private:
