@@ -7,7 +7,7 @@
  * Description : implementation of album view interface.
  *
  * Copyright (C) 2002-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2002-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2002-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2011 by Johannes Wienke <languitar at semipol dot de>
  * Copyright (C) 2010-2011 by Andi Clemens <andi dot clemens at googlemail dot com>
  *
@@ -38,8 +38,13 @@
 #include <khbox.h>
 #include <kurl.h>
 
+// libkexiv2 includes
+
+#include <libkexiv2/rotationmatrix.h>
+
 // Local includes
 
+#include "config-digikam.h"
 #include "searchtextbar.h"
 #include "imageinfo.h"
 #include "digikammodelcollection.h"
@@ -52,6 +57,7 @@ class AlbumSettings;
 class Album;
 class BatchSyncMetadata;
 class FilterStatusBar;
+class SlideShowSettings;
 
 class DigikamView : public KHBox
 {
@@ -74,6 +80,7 @@ public:
     bool isThumbBarVisible();
     void setRecurseAlbums(bool recursive);
     void setRecurseTags(bool recursive);
+    void imageTransform(KExiv2Iface::RotationMatrix::TransformationAction transform);
 
     void connectIconViewFilter(FilterStatusBar* filter);
 
@@ -190,6 +197,10 @@ public Q_SLOTS:
     void slotLeftSideBarActivateAlbums();
     void slotLeftSideBarActivateTags();
 
+#ifdef USE_PRESENTATION_MODE
+    void slotSlideShowQml();
+#endif // USE_PRESENTATION_MODE
+
 private:
 
     void toggleZoomActions();
@@ -198,7 +209,6 @@ private:
     void saveViewState();
     void changeAlbumFromHistory(Album* album, QWidget* widget);
     void slideShow(const ImageInfoList& infoList);
-    void connectBatchSyncMetadata(BatchSyncMetadata* syncMetadata);
 
 private Q_SLOTS:
 
@@ -209,7 +219,6 @@ private Q_SLOTS:
     void slotImageSelected();
     void slotTogglePreviewMode(const ImageInfo& info);
     void slotDispatchImageSelected();
-    void slotItemsInfoFromAlbums(const ImageInfoList&);
 
     void slotLeftSidebarChangedTab(QWidget* w);
 
@@ -221,14 +230,15 @@ private Q_SLOTS:
 
     void slotViewModeChanged();
     void slotEscapePreview();
-    void slotCancelSlideShow();
+
+    void slotSlideShowBuilderComplete(const SlideShowSettings& settings);
 
     void slotThumbSizeEffect();
     void slotZoomFactorChanged(double);
 
     void slotSidebarTabTitleStyleChanged();
 
-    void slotOrientationChangeFailed(const QStringList& failedFileNames);
+    void slotImageChangeFailed(const QString& message, const QStringList& fileNames);
 
     void slotRatingChanged(const KUrl&, int);
     void slotColorLabelChanged(const KUrl&, int);
