@@ -6,11 +6,11 @@
  * Date        : 2005-05-07
  * Description : a dialog to delete item.
  *
- * Copyright (C) 2004 by Michael Pyne <michael.pyne@kdemail.net>
- * Copyright (C) 2006 by Ian Monroe <ian@monroe.nu>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at googlemail dot com>
+ * Copyright (C) 2004      by Michael Pyne <michael.pyne@kdemail.net>
+ * Copyright (C) 2006      by Ian Monroe <ian@monroe.nu>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at googlemail dot com>
  * Copyright (C) 2006-2011 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
- * Copyright (C) 2008-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -70,24 +70,28 @@ public:
     KUrl url;
 };
 
-DeleteItem::DeleteItem(QTreeWidget* parent, const KUrl& url)
+DeleteItem::DeleteItem(QTreeWidget* const parent, const KUrl& url)
     : QTreeWidgetItem(parent), d(new DeleteItemPriv)
 {
     d->url = url;
-    setThumb(SmallIcon("image-x-generic", parent->iconSize().width(), KIconLoader::DisabledState), false);
 
-    if ( d->url.isLocalFile() ) //path is null for non-local
+    if (d->url.protocol() == "digikamalbums")
     {
-        setText(1, d->url.toLocalFile() );
-    }
-    else if ( d->url.protocol() == "digikamalbums")
-    {
-        setText(1, DatabaseUrl(d->url).fileUrl().toLocalFile() );
+        if (DatabaseUrl(d->url).isAlbumUrl())
+        {
+            setThumb(SmallIcon("folder", parent->iconSize().width()));
+        }
+        else
+        {
+            setThumb(SmallIcon("tag", parent->iconSize().width()));
+        }
     }
     else
     {
-        setText(1, d->url.prettyUrl() );
+        setThumb(SmallIcon("image-x-generic", parent->iconSize().width(), KIconLoader::DisabledState), false);
     }
+
+    setText(1, fileUrl());
 }
 
 DeleteItem::~DeleteItem()
@@ -105,6 +109,19 @@ KUrl DeleteItem::url() const
     return d->url;
 }
 
+QString DeleteItem::fileUrl() const
+{
+    if (d->url.isLocalFile())
+    {
+        return (d->url.toLocalFile());
+    }
+    else if (d->url.protocol() == "digikamalbums")
+    {
+        return (DatabaseUrl(d->url).fileUrl().toLocalFile());
+    }
+    return (d->url.prettyUrl());
+}
+
 void DeleteItem::setThumb(const QPixmap& pix, bool hasThumb)
 {
     int iconSize = treeWidget()->iconSize().width();
@@ -145,7 +162,7 @@ public:
     ThumbnailLoadThread* thumbLoadThread;
 };
 
-DeleteItemList::DeleteItemList(QWidget* parent)
+DeleteItemList::DeleteItemList(QWidget* const parent)
     : QTreeWidget(parent), d(new DeleteItemListPriv)
 {
     d->thumbLoadThread = ThumbnailLoadThread::defaultThread();
@@ -159,11 +176,11 @@ DeleteItemList::DeleteItemList(QWidget* parent)
     setHeaderLabels(QStringList() << i18n("Thumb") << i18n("Path"));
     header()->setResizeMode(0, QHeaderView::ResizeToContents);
     header()->setResizeMode(1, QHeaderView::Stretch);
-    setToolTip(i18n("List of files that are about to be deleted."));
+    setToolTip(i18n("List of items that are about to be deleted."));
     setWhatsThis(i18n("This is the list of items that are about to be deleted."));
 
-    connect(d->thumbLoadThread, SIGNAL(signalThumbnailLoaded(LoadingDescription,QPixmap)),
-            this, SLOT(slotThumbnailLoaded(LoadingDescription,QPixmap)));
+    connect(d->thumbLoadThread, SIGNAL(signalThumbnailLoaded(LoadingDescription, QPixmap)),
+            this, SLOT(slotThumbnailLoaded(LoadingDescription, QPixmap)));
 }
 
 DeleteItemList::~DeleteItemList()
@@ -179,12 +196,13 @@ void DeleteItemList::slotThumbnailLoaded(const LoadingDescription& desc, const Q
     {
         DeleteItem* item = dynamic_cast<DeleteItem*>(*it);
 
-        if (item->url().toLocalFile() == desc.filePath)
+        if (item && item->fileUrl() == desc.filePath)
         {
             if (!pix.isNull())
             {
                 item->setThumb(pix.scaled(d->iconSize, d->iconSize, Qt::KeepAspectRatio));
             }
+            return;
         }
 
         ++it;
@@ -194,10 +212,12 @@ void DeleteItemList::slotThumbnailLoaded(const LoadingDescription& desc, const Q
 void DeleteItemList::drawRow(QPainter* p, const QStyleOptionViewItem& opt, const QModelIndex& index) const
 {
     DeleteItem* item = dynamic_cast<DeleteItem*>(itemFromIndex(index));
+
     if (item && !item->hasValidThumbnail())
     {
-        d->thumbLoadThread->find(item->url().toLocalFile());
+        d->thumbLoadThread->find(item->fileUrl());
     }
+
     QTreeWidget::drawRow(p, opt, index);
 }
 
@@ -235,7 +255,7 @@ public:
     DeleteDialogMode::DeleteMode deleteMode;
 };
 
-DeleteWidget::DeleteWidget(QWidget* parent)
+DeleteWidget::DeleteWidget(QWidget* const parent)
     : QWidget(parent), d(new DeleteWidgetPriv)
 {
     setObjectName("DeleteDialogBase");
@@ -277,13 +297,13 @@ DeleteWidget::DeleteWidget(QWidget* parent)
     d->shouldDelete->setGeometry(QRect(0, 0, 542, 32));
     d->shouldDelete->setToolTip(i18n("If checked, files will be permanently removed instead of being placed "
                                     "in the Trash."));
-    d->shouldDelete->setWhatsThis(i18n("<p>If this box is checked, files will be "
+    d->shouldDelete->setWhatsThis(i18n("<p>If this box is checked, items will be "
                                       "<b>permanently removed</b> instead of "
                                       "being placed in the Trash.</p>"
                                       "<p><em>Use this option with caution</em>: most filesystems "
                                       "are unable to "
-                                      "undelete deleted files reliably.</p>"));
-    d->shouldDelete->setText(i18n("&Delete files instead of moving them to the trash"));
+                                      "undelete deleted items reliably.</p>"));
+    d->shouldDelete->setText(i18n("&Delete items instead of moving them to the trash"));
 
     connect(d->shouldDelete, SIGNAL(toggled(bool)),
             this, SLOT(slotShouldDelete(bool)));
@@ -315,13 +335,13 @@ DeleteWidget::~DeleteWidget()
     delete d;
 }
 
-void DeleteWidget::setFiles(const KUrl::List& files)
+void DeleteWidget::setUrls(const KUrl::List& urls)
 {
     d->fileList->clear();
 
-    for ( KUrl::List::ConstIterator it = files.begin(); it != files.end(); ++it)
+    foreach(KUrl url, urls)
     {
-        new DeleteItem(d->fileList, *it);
+        new DeleteItem(d->fileList, url);
     }
 
     updateText();
@@ -349,17 +369,17 @@ void DeleteWidget::updateText()
     // set "do not ask again checkbox text
     if (d->deleteMode == DeleteDialogMode::DeletePermanently)
     {
-        d->doNotShowAgain->setToolTip(i18n("If checked, this dialog will no longer be shown, and files will "
+        d->doNotShowAgain->setToolTip(i18n("If checked, this dialog will no longer be shown, and items will "
                                            "be directly and permanently deleted."));
         d->doNotShowAgain->setWhatsThis(i18n("If this box is checked, this dialog will no longer be shown, "
-                                             "and files will be directly and permanently deleted."));
+                                             "and items will be directly and permanently deleted."));
     }
     else
     {
-        d->doNotShowAgain->setToolTip(i18n("If checked, this dialog will no longer be shown, and files will "
+        d->doNotShowAgain->setToolTip(i18n("If checked, this dialog will no longer be shown, and items will "
                                            "be directly moved to the Trash."));
         d->doNotShowAgain->setWhatsThis(i18n("If this box is checked, this dialog will no longer be shown, "
-                                             "and files will be directly moved to the Trash."));
+                                             "and items will be directly moved to the Trash."));
     }
 
     switch (d->listMode)
@@ -380,7 +400,7 @@ void DeleteWidget::updateText()
                 d->deleteText->setText(i18n("These items will be moved to Trash."));
                 d->warningIcon->setPixmap(KIconLoader::global()->loadIcon("user-trash-full",
                                           KIconLoader::Desktop, KIconLoader::SizeLarge));
-                d->numFiles->setText(i18np("<b>1</b> file selected.", "<b>%1</b> files selected.",
+                d->numFiles->setText(i18np("<b>1</b> item selected.", "<b>%1</b> items selected.",
                                            d->fileList->topLevelItemCount()));
             }
 
@@ -463,7 +483,7 @@ public:
     DeleteWidget* widget;
 };
 
-DeleteDialog::DeleteDialog(QWidget* parent)
+DeleteDialog::DeleteDialog(QWidget* const parent)
     : KDialog(parent), d(new DeleteDialogPriv)
 {
     setButtons(User1 | Cancel);
@@ -494,7 +514,7 @@ bool DeleteDialog::confirmDeleteList(const KUrl::List& condemnedFiles,
                                      DeleteDialogMode::ListMode listMode,
                                      DeleteDialogMode::DeleteMode deleteMode)
 {
-    setURLs(condemnedFiles);
+    setUrls(condemnedFiles);
     presetDeleteMode(deleteMode);
     setListMode(listMode);
 
@@ -516,9 +536,9 @@ bool DeleteDialog::confirmDeleteList(const KUrl::List& condemnedFiles,
     return exec() == QDialog::Accepted;
 }
 
-void DeleteDialog::setURLs(const KUrl::List& files)
+void DeleteDialog::setUrls(const KUrl::List& urls)
 {
-    d->widget->setFiles(files);
+    d->widget->setUrls(urls);
 }
 
 void DeleteDialog::slotUser1Clicked()
@@ -607,7 +627,7 @@ void DeleteDialog::setListMode(DeleteDialogMode::ListMode mode)
     switch (mode)
     {
         case DeleteDialogMode::Files:
-            setCaption(i18n("About to delete selected files"));
+            setCaption(i18n("About to delete selected items"));
             break;
 
         case DeleteDialogMode::Albums:
@@ -641,5 +661,4 @@ void DeleteDialog::keyPressEvent(QKeyEvent* e)
     KDialog::keyPressEvent(e);
 }
 
-
 } // namespace Digikam
