@@ -6,8 +6,8 @@
  * Date        : 2008-07-11
  * Description : general info list dialog
  *
- * Copyright (C) 2008-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at googlemail dot com>
+ * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009      by Andi Clemens <andi dot clemens at googlemail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -62,7 +62,7 @@ public:
     QTreeWidget* listView;
 };
 
-InfoDlg::InfoDlg(QWidget* parent)
+InfoDlg::InfoDlg(QWidget* const parent)
     : KDialog(parent), d(new InfoDlgPriv)
 {
     setButtons(Help|User1|Ok);
