@@ -228,7 +228,7 @@ bool JPEGLoader::load(const QString& filePath, DImgLoaderObserver* observer)
         inFile.close();
     }
 
-    jpeg_memory_src(&cinfo, (JOCTET*)buffer.data(), buffer.size());
+    JPEGUtils::jpeg_memory_src(&cinfo, (JOCTET*)buffer.data(), buffer.size());
 #else
     jpeg_stdio_src(&cinfo, file);
 #endif
@@ -786,6 +786,7 @@ bool JPEGLoader::save(const QString& filePath, DImgLoaderObserver* observer)
 
     if (!profile_rawdata.isEmpty())
     {
+        purgeExifWorkingColorSpace();
         write_icc_profile(&cinfo, (JOCTET*)profile_rawdata.data(), profile_rawdata.size());
     }
 
