@@ -6,7 +6,7 @@
  * Date        : 2009-07-09
  * Description : Subjects panel.
  *
- * Copyright (C) 2009-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -38,7 +38,7 @@ class SubjectEdit : public SubjectWidget
 
 public:
 
-    SubjectEdit(QWidget* parent);
+    SubjectEdit(QWidget* const parent);
     ~SubjectEdit();
 
 private Q_SLOTS:
