@@ -26,7 +26,7 @@
 
 // KDE includes
 
-#include <KDialog>
+#include <kdialog.h>
 
 // local includes
 
