@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2009-11-13
  * Description : a plugin to blend bracketed images.
  *
- * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,6 +24,7 @@
 
 // Qt includes
 
+#include <QDir>
 #include <QLabel>
 #include <QVBoxLayout>
 #include <QTimer>
@@ -49,7 +50,8 @@
 
 // Local includes
 
-#include "outputdialog.h"
+#include "aboutdata.h"
+#include "kpoutputdialog.h"
 #include "alignbinary.h"
 #include "manager.h"
 #include "actionthread.h"
@@ -91,9 +93,9 @@ public:
     Manager*        mngr;
 };
 
-PreProcessingPage::PreProcessingPage(Manager* mngr, KAssistantDialog* dlg)
-                 : WizardPage(dlg, i18n("<b>Pre-Processing Bracketed Images</b>")),
-                   d(new PreProcessingPagePriv)
+PreProcessingPage::PreProcessingPage(Manager* const mngr, KAssistantDialog* const dlg)
+    : KPWizardPage(dlg, i18n("<b>Pre-Processing Bracketed Images</b>")),
+      d(new PreProcessingPagePriv)
 {
     d->mngr          = mngr;
     d->progressTimer = new QTimer(this);
@@ -164,7 +166,7 @@ void PreProcessingPage::resetTitle()
                            "to 16-bit sRGB images with auto-gamma.</p>"
                            "<p>Press \"Next\" to start pre-processing.</p>"
                            "</qt>",
-                           QString(d->mngr->alignBinary().path()),
+                           QDir::toNativeSeparators(d->mngr->alignBinary().path()),
                            d->mngr->alignBinary().url().url(),
                            d->mngr->alignBinary().projectName()));
     d->detailsBtn->hide();
@@ -185,7 +187,7 @@ void PreProcessingPage::process()
             this, SLOT(slotAction(KIPIExpoBlendingPlugin::ActionData)));
 
     d->mngr->thread()->setPreProcessingSettings(d->alignCheckBox->isChecked(), d->mngr->rawDecodingSettings());
-    d->mngr->thread()->preProcessFiles(d->mngr->itemsList());
+    d->mngr->thread()->preProcessFiles(d->mngr->itemsList(), d->mngr->alignBinary().path());
     if (!d->mngr->thread()->isRunning())
         d->mngr->thread()->start();
 }
@@ -214,11 +216,11 @@ void PreProcessingPage::slotProgressTimerDone()
 
 void PreProcessingPage::slotShowDetails()
 {
-    OutputDialog dlg(kapp->activeWindow(),
-                     i18n("Pre-Processing Messages"),
-                     d->output);
-                     i18n("Pre-Processing Messages"),
-    dlg.setAboutData((KPAboutData*)d->mngr->about(), QString("expoblending"));
+    KPOutputDialog dlg(kapp->activeWindow(),
+                       i18n("Pre-Processing Messages"),
+                       d->output);
+
+    dlg.setAboutData(new ExpoBlendingAboutData());
     dlg.exec();
 }
 
