@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2005-12-19
  * Description : a plugin to export image collections using SimpleViewer.
  *
  * Copyright (C) 2005-2006 by Joern Ahrens <joern dot ahrens at kdemail dot net>
- * Copyright (C) 2008-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2011 by Veaceslav Munteanu <slavuttici@gmail.com>
+ * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011      by Veaceslav Munteanu <slavuttici@gmail.com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -48,10 +48,6 @@
 #include <ktempdir.h>
 #include <ktoolinvocation.h>
 
-// LibKIPI includes
-
-#include <libkipi/imageinfo.h>
-
 // LibKDcraw includes
 
 #include <libkdcraw/version.h>
@@ -59,8 +55,9 @@
 
 // Local includes
 
-#include "pluginsversion.h"
-
+#include "kpversion.h"
+#include "kpimageinfo.h"
+#include "kpmetadata.h"
 
 namespace KIPIFlashExportPlugin
 {
@@ -69,7 +66,9 @@ class SimpleViewer::SimpleViewerPriv
 {
 public:
 
-    SimpleViewerPriv() : maxThumbSize(45), viewer("simpleviewer.swf")
+    SimpleViewerPriv() :
+        maxThumbSize(45),
+        viewer("simpleviewer.swf")
     {
         totalActions = 0;
         action       = 0;
@@ -102,16 +101,14 @@ public:
 
     KTempDir*                         tempDir;
 
-    QList<KIPI::ImageCollection>      collectionsList;
+    Interface*                        interface;
 
-    KIPI::Interface*                  interface;
-
-    KIPIPlugins::BatchProgressWidget* progressWdg;
+    KPBatchProgressWidget*            progressWdg;
 
     SimpleViewerSettingsContainer*    settings;
 };
 
-SimpleViewer::SimpleViewer(KIPI::Interface* interface, QObject* parent)
+SimpleViewer::SimpleViewer(Interface* const interface, QObject* const parent)
     : QObject(parent), d(new SimpleViewerPriv)
 {
     d->interface = interface;
@@ -121,7 +118,7 @@ SimpleViewer::SimpleViewer(KIPI::Interface* interface, QObject* parent)
     if (d->hostUrl.isEmpty())
     {
         d->hostName = QString("Kipi");
-        d->hostUrl  = QString("http://www.kipi-plugins.org");
+        d->hostUrl  = QString("http://www.digikam.org");
     }
 }
 
@@ -133,46 +130,46 @@ SimpleViewer::~SimpleViewer()
 
 void SimpleViewer::appendPluginFiles(int pluginType)
 {
-	kDebug() << "Value of plugin type in append files" << pluginType;
-	switch(pluginType)
-	{
-		case 0:
-			d->simpleViewerFiles.clear();
-			d->simpleViewerFiles.append("web/svcore/swf/simpleviewer.swf");
-			d->simpleViewerFiles.append("web/svcore/js/swfobject.js");
-	                d->dataLocal = KStandardDirs::locateLocal("data", "kipiplugin_flashexport/simpleviewer/", true);
-	                d->dataDir   = KStandardDirs::locate("data", "kipiplugin_flashexport/simpleviewer/");
-	                kDebug() << "Data dir when set is " << d->dataDir;
-			break;
-		case 1:
-			d->simpleViewerFiles.clear();
-			d->simpleViewerFiles.append("autoviewer.swf");
-			d->simpleViewerFiles.append("swfobject.js");
-			d->dataLocal = KStandardDirs::locateLocal("data", "kipiplugin_flashexport/autoviewer/", true);
-	                d->dataDir   = KStandardDirs::locate("data", "kipiplugin_flashexport/autoviewer/");
-			break;
-		case 2:
-			d->simpleViewerFiles.clear();
-			d->simpleViewerFiles.append("TiltViewer.swf");
-			d->simpleViewerFiles.append("swfobject.js");
-			d->dataLocal = KStandardDirs::locateLocal("data", "kipiplugin_flashexport/tiltviewer/", true);
+    kDebug() << "Value of plugin type in append files" << pluginType;
+    switch(pluginType)
+    {
+        case 0:
+            d->simpleViewerFiles.clear();
+            d->simpleViewerFiles.append("web/svcore/swf/simpleviewer.swf");
+            d->simpleViewerFiles.append("web/svcore/js/swfobject.js");
+                    d->dataLocal = KStandardDirs::locateLocal("data", "kipiplugin_flashexport/simpleviewer/", true);
+                    d->dataDir   = KStandardDirs::locate("data", "kipiplugin_flashexport/simpleviewer/");
+                    kDebug() << "Data dir when set is " << d->dataDir;
+            break;
+        case 1:
+            d->simpleViewerFiles.clear();
+            d->simpleViewerFiles.append("autoviewer.swf");
+            d->simpleViewerFiles.append("swfobject.js");
+            d->dataLocal = KStandardDirs::locateLocal("data", "kipiplugin_flashexport/autoviewer/", true);
+                    d->dataDir   = KStandardDirs::locate("data", "kipiplugin_flashexport/autoviewer/");
+            break;
+        case 2:
+            d->simpleViewerFiles.clear();
+            d->simpleViewerFiles.append("TiltViewer.swf");
+            d->simpleViewerFiles.append("swfobject.js");
+            d->dataLocal = KStandardDirs::locateLocal("data", "kipiplugin_flashexport/tiltviewer/", true);
                         d->dataDir   = KStandardDirs::locate("data", "kipiplugin_flashexport/tiltviewer/");
-			break;
-		case 3:
-			d->simpleViewerFiles.clear();
-			d->simpleViewerFiles.append("viewer.swf");
-			d->simpleViewerFiles.append("swfobject.js");
-			d->dataLocal = KStandardDirs::locateLocal("data", "kipiplugin_flashexport/postcardviewer/", true);
+            break;
+        case 3:
+            d->simpleViewerFiles.clear();
+            d->simpleViewerFiles.append("viewer.swf");
+            d->simpleViewerFiles.append("swfobject.js");
+            d->dataLocal = KStandardDirs::locateLocal("data", "kipiplugin_flashexport/postcardviewer/", true);
                         d->dataDir   = KStandardDirs::locate("data", "kipiplugin_flashexport/postcardviewer/");
-			break;
-		default:
-			break;
-	}
+            break;
+        default:
+            break;
+    }
 }
 
-void SimpleViewer::initProgressWdg()
+void SimpleViewer::initProgressWdg() const
 {
-    d->progressWdg = new KIPIPlugins::BatchProgressWidget(kapp->activeWindow());
+    d->progressWdg = new KPBatchProgressWidget(kapp->activeWindow());
     kDebug() << "progress dialog initialized";
 }
 
@@ -183,16 +180,22 @@ void SimpleViewer::startExport()
 
      kDebug() << "SimpleViewer started...";
     // Estimate the number of actions for the KIPIPlugins progress dialog.
-    d->progressWdg->addedAction(i18n("Initialising..."), KIPIPlugins::StartingMessage);
-    d->collectionsList = d->settings->collections;
+    d->progressWdg->addedAction(i18n("Initialising..."), StartingMessage);
     d->totalActions    = 0;
     d->action          = 0;
     d->progressWdg->reset();
 
-    for( QList<KIPI::ImageCollection>::ConstIterator it = d->collectionsList.constBegin() ;
-         !d->canceled && (it != d->collectionsList.constEnd()) ; ++it )
+    if(d->settings->imgGetOption == 0)
     {
-        d->totalActions += (*it).images().count();
+        for( QList<ImageCollection>::ConstIterator it = d->settings->collections.constBegin() ;
+            !d->canceled && (it != d->settings->collections.constEnd()) ; ++it )
+        {
+            d->totalActions += (*it).images().count();
+        }
+    }
+    else
+    {
+        d->totalActions+=d->settings->imageDialogList.count();
     }
 
     // +copying SimpleViewer, +creating index.html
@@ -205,7 +208,7 @@ void SimpleViewer::startExport()
 
 void SimpleViewer::slotCancel()
 {
-    d->progressWdg->addedAction(i18n("Export canceled"), KIPIPlugins::ErrorMessage);
+    d->progressWdg->addedAction(i18n("Export canceled"), ErrorMessage);
     d->canceled = true;
 }
 
@@ -217,35 +220,35 @@ void SimpleViewer::slotProcess()
     if(!d->canceled && !createExportDirectories())
     {
             d->progressWdg->addedAction(i18n("Failed to create export directories"),
-                                       KIPIPlugins::ErrorMessage);
+                                       ErrorMessage);
         return;
     }
 
     if(!d->canceled && !exportImages())
     {
         d->progressWdg->addedAction(i18n("Failed to export the images"),
-                                   KIPIPlugins::ErrorMessage);
+                                   ErrorMessage);
         return;
     }
 
     if(!d->canceled && !createIndex())
     {
         d->progressWdg->addedAction(i18n("Failed to create index.html"),
-                                   KIPIPlugins::ErrorMessage);
+                                   ErrorMessage);
         return;
     }
 
     if(!d->canceled && !copySimpleViewer())
     {
         d->progressWdg->addedAction(i18n("Failed to copy SimpleViewer files"),
-                                   KIPIPlugins::ErrorMessage);
+                                   ErrorMessage);
         return;
     }
 
     if(!d->canceled && !upload())
     {
         d->progressWdg->addedAction(i18n("Failed to upload the gallery"),
-                                   KIPIPlugins::ErrorMessage);
+                                   ErrorMessage);
         return;
     }
 
@@ -265,10 +268,10 @@ void SimpleViewer::slotProcess()
     if(!d->canceled)
     {
         d->progressWdg->addedAction(i18nc("Flash export has finished", "Finished..."),
-                                    KIPIPlugins::SuccessMessage);
-    	emit signalProcessingDone();
+                                    SuccessMessage);
+        emit signalProcessingDone();
         if(d->settings->openInKonqueror)
-        	KToolInvocation::invokeBrowser(d->settings->exportUrl.path());
+            KToolInvocation::invokeBrowser(d->settings->exportUrl.path());
     }
 }
 
@@ -278,14 +281,14 @@ bool SimpleViewer::createExportDirectories() const
     d->tempDir = new KTempDir(KStandardDirs::locateLocal("tmp", "flashexport"));
     d->tempDir->setAutoRemove(true);
 
-    d->progressWdg->addedAction(i18n("Creating directories..."), KIPIPlugins::StartingMessage);
+    d->progressWdg->addedAction(i18n("Creating directories..."), StartingMessage);
 
     KUrl root = d->settings->exportUrl;
     kDebug() << "export url is" << root.url();
     if(!KIO::NetAccess::mkdir(root, kapp->activeWindow()))
     {
         d->progressWdg->addedAction(i18n("Could not create folder '%1'", root.url()),
-                                    KIPIPlugins::ErrorMessage);
+                                    ErrorMessage);
         return false;
     }
 
@@ -297,7 +300,7 @@ bool SimpleViewer::createExportDirectories() const
         if(!KIO::NetAccess::mkdir(thumbsDir, kapp->activeWindow()))
         {
             d->progressWdg->addedAction(i18n("Could not create folder '%1'", thumbsDir.url()),
-                                   KIPIPlugins::ErrorMessage);
+                                   ErrorMessage);
             return false;
         }
     }
@@ -309,53 +312,44 @@ bool SimpleViewer::createExportDirectories() const
     if(!KIO::NetAccess::mkdir(imagesDir, kapp->activeWindow()))
     {
         d->progressWdg->addedAction(i18n("Could not create folder '%1'", imagesDir.url()),
-                                    KIPIPlugins::ErrorMessage);
+                                    ErrorMessage);
         return false;
     }
 
-    d->progressWdg->addedAction(i18n("Finished Creating directories..."), KIPIPlugins::StartingMessage);
+    d->progressWdg->addedAction(i18n("Finished Creating directories..."), StartingMessage);
     d->progressWdg->setProgress(++d->action, d->totalActions);
 
     return true;
 }
 
-bool SimpleViewer::cmpUrl(const KUrl &url1, const KUrl &url2)
+bool SimpleViewer::cmpUrl(const KUrl& url1, const KUrl& url2)
 {
+    KPMetadata meta;
+    meta.load(url1.path());
+    QDateTime clock1 = meta.getImageDateTime();
 
-    KExiv2Iface::KExiv2 meta1;
-    meta1.load(url1.path());
-    QDateTime clock1             = meta1.getImageDateTime();
+    meta.load(url2.path());
+    QDateTime clock2 = meta.getImageDateTime();
 
-    KExiv2Iface::KExiv2 meta2;
-    meta2.load(url2.path());
-    QDateTime clock2             = meta2.getImageDateTime();
-
-    if(clock1.isValid() || clock2.isValid())
+    if (clock1.isValid() || clock2.isValid())
     {
-    	return clock1 < clock2;
+        return clock1 < clock2;
     }
     else
     {
-    	QString name1 = url1.fileName();
-    	QString name2 = url2.fileName();
+        QString name1 = url1.fileName();
+        QString name2 = url2.fileName();
 
-    	return name1 < name2;
+        return (name1 < name2) ;
     }
-
 }
 
-bool SimpleViewer::exportImages() const
+bool SimpleViewer::exportImages()
 {
     if(d->canceled)
         return false;
 
-    d->progressWdg->addedAction(i18n("Creating images and thumbnails..."), KIPIPlugins::StartingMessage);
-
-    KUrl thumbsDir(d->tempDir->name());
-    thumbsDir.addPath("/thumbs");
-
-    KUrl imagesDir(d->tempDir->name());
-    imagesDir.addPath("/images");
+    d->progressWdg->addedAction(i18n("Creating images and thumbnails..."), StartingMessage);
 
     KUrl xmlFile(d->tempDir->name());
     xmlFile.addPath("/gallery.xml");
@@ -363,11 +357,11 @@ bool SimpleViewer::exportImages() const
     file.open(QIODevice::WriteOnly);
 
     // header of gallery.xml
+    QDomElement  galleryElem;
+    QDomElement  photosElem;
     QDomDocument xmlDoc;
     xmlDoc.appendChild(xmlDoc.createProcessingInstruction( QString::fromLatin1("xml"),
                        QString::fromLatin1("version=\"1.0\" encoding=\"UTF-8\"") ) );
-    QDomElement galleryElem;
-    QDomElement photosElem;
 
     switch(d->settings->plugType)
     {
@@ -396,9 +390,9 @@ bool SimpleViewer::exportImages() const
             galleryElem = xmlDoc.createElement(QString::fromLatin1("gallery"));
             xmlDoc.appendChild( galleryElem );
             galleryElem.setAttribute(QString::fromLatin1("enableRightClickOpen"), d->settings->enableRightClickToOpen());
-            galleryElem.setAttribute(QString::fromLatin1("imagePadding"),        d->settings->imagePadding);
-            galleryElem.setAttribute(QString::fromLatin1("displayTime"),       d->settings->displayTime);
-            galleryElem.setAttribute(QString::fromLatin1("frameWidth"),            d->settings->frameWidth);
+            galleryElem.setAttribute(QString::fromLatin1("imagePadding"),         d->settings->imagePadding);
+            galleryElem.setAttribute(QString::fromLatin1("displayTime"),          d->settings->displayTime);
+            galleryElem.setAttribute(QString::fromLatin1("frameWidth"),           d->settings->frameWidth);
             galleryElem.setAttribute(QString::fromLatin1("frameColor"),           d->settings->frameColor.name().replace('#', "0x"));
             galleryElem.setAttribute(QString::fromLatin1("bgColor"),              d->settings->backgroundColor.name().replace('#', "0x"));
             break;
@@ -430,115 +424,20 @@ bool SimpleViewer::exportImages() const
         default:
             break;
     }
-
-    KExiv2Iface::KExiv2 meta;
-    QImage              image;
-    QImage              thumbnail;
-    QString             tmp;
-    QString             newName;
-
-    int index           = 1;
-    int maxSize         = d->settings->imagesExportSize;
-    bool resizeImages   = d->settings->resizeExportImages;
-    bool fixOrientation = d->settings->fixOrientation;
-
-    for( QList<KIPI::ImageCollection>::ConstIterator it = d->collectionsList.constBegin() ;
-         !d->canceled && (it != d->collectionsList.constEnd()) ; ++it )
+    if(d->settings->imgGetOption ==0)
     {
-         KUrl::List images = (*it).images();
-
-         qSort(images.begin(), images.end(), cmpUrl);
-
-        for(KUrl::List::ConstIterator it = images.constBegin();
-            !d->canceled && (it != images.constEnd()) ; ++it)
+        for( QList<ImageCollection>::ConstIterator it = d->settings->collections.constBegin() ;
+            !d->canceled && (it != d->settings->collections.constEnd()) ; ++it )
         {
-            kapp->processEvents();
-            KUrl url = *it;
-            QFileInfo fi(url.path());
-
-            //video can't be exported, need to add for all video files
-            if(fi.suffix().toUpper() == "MOV")
-                continue;
-
-            d->progressWdg->addedAction(i18n("Processing %1", url.fileName()), KIPIPlugins::StartingMessage);
-
-            // Check if RAW file.
-            QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-            if (rawFilesExt.toUpper().contains( fi.suffix().toUpper()))
-                KDcrawIface::KDcraw::loadDcrawPreview(image, url.path());
-            else
-                image.load(url.path());
-
-            if(image.isNull())
-            {
-                d->progressWdg->addedAction(i18n("Could not open image '%1'", url.fileName()),
-                                           KIPIPlugins::WarningMessage);
-                continue;
-            }
-
-            if(d->settings->plugType == 0)
-            {
-                // Thumbnails are generated only for simpleviewer plugin
-
-                if(!createThumbnail(image, thumbnail))
-                {
-                    d->progressWdg->addedAction(i18n("Could not create thumbnail from '%1'", url.fileName()),
-                                           KIPIPlugins::WarningMessage);
-                    continue;
-                }
-            }
-
-            if(resizeImages && !resizeImage(image, maxSize, image))
-            {
-                d->progressWdg->addedAction(i18n("Could not resize image '%1'", url.fileName()),
-                                           KIPIPlugins::WarningMessage);
-                continue;
-            }
-
-            meta.load(url.path());
-            bool rotated = false;
-            newName      = QString("%1.%2").arg(tmp.sprintf("%03i", index)).arg(QString("jpg"));
-
-            if(d->settings->plugType == 0)
-            {
-                KUrl thumbnailPath(thumbsDir);
-                thumbnailPath.addPath(newName);
-
-                if (resizeImages && fixOrientation)
-                    meta.rotateExifQImage(thumbnail, meta.getImageOrientation());
-
-                thumbnail.save(thumbnailPath.path(), "JPEG");
-            }
-
-            KUrl imagePath(imagesDir);
-            imagePath.addPath(newName);
-
-            if (resizeImages && fixOrientation)
-                rotated = meta.rotateExifQImage(image, meta.getImageOrientation());
-
-            image.save(imagePath.path(), "JPEG");
-
-            // Backup metadata from original image.
-            meta.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
-            meta.setImageDimensions(image.size());
-
-            if (rotated)
-                meta.setImageOrientation(KExiv2Iface::KExiv2::ORIENTATION_NORMAL);
-
-            meta.save(imagePath.path());
-
-            d->width  = image.width();
-            d->height = image.height();
-
-            if(d->settings->plugType!=2)
-                cfgAddImage(xmlDoc, galleryElem, url, newName);
-            else
-                cfgAddImage(xmlDoc, photosElem, url, newName);
-
-            d->progressWdg->setProgress(++d->action, d->totalActions);
-            index++;
+            KUrl::List images = (*it).images();
+            processKUrlList(images,xmlDoc,galleryElem,photosElem);
         }
     }
+    else
+    {
+        KUrl::List images = d->settings->imageDialogList;
+        processKUrlList(images,xmlDoc,galleryElem,photosElem);
+    }
 
     QByteArray data(xmlDoc.toByteArray());
     QDataStream stream( &file );
@@ -547,7 +446,117 @@ bool SimpleViewer::exportImages() const
 
     return true;
 }
+void SimpleViewer::processKUrlList(KUrl::List& images, QDomDocument& xmlDoc,
+                                   QDomElement& galleryElem, QDomElement& photosElem)
+{
+    KPMetadata meta;
+    QImage     image;
+    QImage     thumbnail;
+    QString    tmp;
+    QString    newName;
 
+    int index           = 1;
+    int maxSize         = d->settings->imagesExportSize;
+    bool resizeImages   = d->settings->resizeExportImages;
+    bool fixOrientation = d->settings->fixOrientation;
+
+    KUrl thumbsDir(d->tempDir->name());
+    thumbsDir.addPath("/thumbs");
+
+    KUrl imagesDir(d->tempDir->name());
+    imagesDir.addPath("/images");
+
+    qSort(images.begin(), images.end(), cmpUrl);
+
+    for(KUrl::List::ConstIterator it = images.constBegin();
+        !d->canceled && (it != images.constEnd()) ; ++it)
+    {
+        kapp->processEvents();
+        KUrl url = *it;
+        QFileInfo fi(url.path());
+
+        //video can't be exported, need to add for all video files
+        if(fi.suffix().toUpper() == "MOV")
+            continue;
+
+        d->progressWdg->addedAction(i18n("Processing %1", url.fileName()), StartingMessage);
+
+        // Check if RAW file.
+        if (KPMetadata::isRawFile(url))
+            KDcrawIface::KDcraw::loadDcrawPreview(image, url.path());
+        else
+            image.load(url.path());
+
+        if(image.isNull())
+        {
+            d->progressWdg->addedAction(i18n("Could not open image '%1'", url.fileName()),
+                                        WarningMessage);
+            continue;
+        }
+
+        if(d->settings->plugType == 0)
+        {
+            // Thumbnails are generated only for simpleviewer plugin
+
+            if(!createThumbnail(image, thumbnail))
+            {
+                d->progressWdg->addedAction(i18n("Could not create thumbnail from '%1'", url.fileName()),
+                                        WarningMessage);
+                continue;
+            }
+        }
+
+        if(resizeImages && !resizeImage(image, maxSize, image))
+        {
+            d->progressWdg->addedAction(i18n("Could not resize image '%1'", url.fileName()),
+                                        WarningMessage);
+            continue;
+        }
+
+        meta.load(url.path());
+        bool rotated = false;
+        newName      = QString("%1.%2").arg(tmp.sprintf("%03i", index)).arg(QString("jpg"));
+
+        if(d->settings->plugType == 0)
+        {
+            KUrl thumbnailPath(thumbsDir);
+            thumbnailPath.addPath(newName);
+
+            if (resizeImages && fixOrientation)
+                meta.rotateExifQImage(thumbnail, meta.getImageOrientation());
+
+            thumbnail.save(thumbnailPath.path(), "JPEG");
+        }
+
+        KUrl imagePath(imagesDir);
+        imagePath.addPath(newName);
+
+        if (resizeImages && fixOrientation)
+            rotated = meta.rotateExifQImage(image, meta.getImageOrientation());
+
+        image.save(imagePath.path(), "JPEG");
+
+        // Backup metadata from original image.
+        meta.setImageProgramId(QString("Kipi-plugins"), QString(kipiplugins_version));
+        meta.setImageDimensions(image.size());
+
+        if (rotated)
+            meta.setImageOrientation(KPMetadata::ORIENTATION_NORMAL);
+
+        meta.save(imagePath.path());
+
+        d->width  = image.width();
+        d->height = image.height();
+
+        if(d->settings->plugType!=2)
+            cfgAddImage(xmlDoc, galleryElem, url, newName);
+        else
+            cfgAddImage(xmlDoc, photosElem, url, newName);
+
+        d->progressWdg->setProgress(++d->action, d->totalActions);
+        index++;
+    }
+}
 bool SimpleViewer::createThumbnail(const QImage& image, QImage& thumbnail) const
 {
     int w = image.width();
@@ -607,22 +616,19 @@ void SimpleViewer::cfgAddImage(QDomDocument& xmlDoc, QDomElement& galleryElem,
     QString comment;
     QString keywords;
 
+    KPImageInfo info(url);
+
     if(d->settings->showComments)
     {
-        KIPI::ImageInfo info = d->interface->info(url);
-        comment              = info.description();
+        comment = info.description();
     }
     else
     {
         comment.clear();
     }
-
-    if(d->settings->showKeywords && d->interface->hasFeature(KIPI::HostSupportsTags))
+    if(d->settings->showKeywords)
     {
-        KIPI::ImageInfo info            = d->interface->info(url);
-        QMap<QString, QVariant> attribs = info.attributes();
-        QStringList tagList             = attribs["tags"].toStringList();
-
+        QStringList tagList = info.keywords();
         if(!tagList.join(" ").isEmpty())
             keywords = QString("\nTags: ")+tagList.join(", ");
     }
@@ -721,7 +727,6 @@ void SimpleViewer::cfgAddImage(QDomDocument& xmlDoc, QDomElement& galleryElem,
         default:
             break;
     }
-
 }
 
 bool SimpleViewer::createIndex() const
@@ -729,7 +734,7 @@ bool SimpleViewer::createIndex() const
     if(d->canceled)
         return false;
 
-    d->progressWdg->addedAction(i18n("Creating index.html..."), KIPIPlugins::StartingMessage);
+    d->progressWdg->addedAction(i18n("Creating index.html..."), StartingMessage);
 
     switch(d->settings->plugType)
     {
@@ -868,7 +873,7 @@ bool SimpleViewer::createIndex() const
     }
 
     d->progressWdg->setProgress(++d->action, d->totalActions);
-    d->progressWdg->addedAction(i18n("index.html created..."), KIPIPlugins::SuccessMessage);
+    d->progressWdg->addedAction(i18n("index.html created..."), SuccessMessage);
 
     return true;
 }
@@ -878,7 +883,7 @@ bool SimpleViewer::copySimpleViewer() const
     if(d->canceled)
         return false;
 
-    d->progressWdg->addedAction(i18n("Copying flash files..."), KIPIPlugins::StartingMessage);
+    d->progressWdg->addedAction(i18n("Copying flash files..."), StartingMessage);
 
     // Due to its license, simpleviewer is installed in $KDEHOME
     KUrl::List  files;
@@ -896,7 +901,7 @@ bool SimpleViewer::copySimpleViewer() const
     // TODO: catch errors
     /*KIO::CopyJob *copyJob =*/ KIO::copy(files, d->settings->exportUrl, KIO::HideProgressInfo);
 
-    d->progressWdg->addedAction(i18n("Flash files copied..."), KIPIPlugins::SuccessMessage);
+    d->progressWdg->addedAction(i18n("Flash files copied..."), SuccessMessage);
 
     return true;
 }
@@ -906,12 +911,12 @@ bool SimpleViewer::upload() const
     if(d->canceled)
         return false;
 
-    d->progressWdg->addedAction(i18n("Uploading gallery..."), KIPIPlugins::StartingMessage);
+    d->progressWdg->addedAction(i18n("Uploading gallery..."), StartingMessage);
 
     if(!KIO::NetAccess::dircopy(KUrl(d->tempDir->name() + "./"), d->settings->exportUrl))
         return false;
 
-    d->progressWdg->addedAction(i18n("Gallery uploaded..."), KIPIPlugins::SuccessMessage);
+    d->progressWdg->addedAction(i18n("Gallery uploaded..."), SuccessMessage);
 
     return true;
 }
@@ -981,7 +986,7 @@ bool SimpleViewer::extractFile(const KArchiveEntry* entry) const
         return false;
 
     const KArchiveFile* entryFile = dynamic_cast<const KArchiveFile*>(entry);
-    QByteArray array = entryFile->data();
+    QByteArray array              = entryFile->data();
 
     QFile file( d->dataLocal + entry->name() );
     if(file.open( QIODevice::WriteOnly ))
@@ -994,15 +999,15 @@ bool SimpleViewer::extractFile(const KArchiveEntry* entry) const
     return false;
 }
 
-KIPIPlugins::BatchProgressWidget* SimpleViewer::progressWidget()
+KPBatchProgressWidget* SimpleViewer::progressWidget() const
 {
-	initProgressWdg();
-	return d->progressWdg;
+    initProgressWdg();
+    return d->progressWdg;
 }
 
-void SimpleViewer::setSettings(SimpleViewerSettingsContainer* setting)
+void SimpleViewer::setSettings(SimpleViewerSettingsContainer* const setting)
 {
-    d->settings=setting;
+    d->settings = setting;
     d->canceled = false;
 
     kDebug() << "Settings reached SimpleViewer";
