@@ -1,12 +1,12 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2006-10-15
  * Description : XMP subjects settings page.
  *
- * Copyright (C) 2006-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at googlemail dot com>
  *
  * This program is free software; you can redistribute it
@@ -33,7 +33,11 @@
 
 #include <libkexiv2/subjectwidget.h>
 
-using namespace KExiv2Iface;
+// Local includes
+
+#include "kpmetadata.h"
+
+using namespace KIPIPlugins;
 
 namespace KIPIMetadataEditPlugin
 {
@@ -44,7 +48,7 @@ class XMPSubjects : public SubjectWidget
 
 public:
 
-    XMPSubjects(QWidget* parent);
+    XMPSubjects(QWidget* const parent);
     ~XMPSubjects();
 
     void applyMetadata(QByteArray& xmpData);
