@@ -1,14 +1,14 @@
 /* ============================================================
  * 
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2011-05-23
  * Description : a plugin to create panorama by fusion of several images.
  * Acknowledge : based on the expoblending plugin
  *
  * Copyright (C) 2011 by Benjamin Girault <benjamin dot girault at gmail dot com>
- * Copyright (C) 2009-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -40,13 +40,9 @@
 #include <klocale.h>
 #include <kapplication.h>
 
-// LibKIPI includes
-
-#include <libkipi/interface.h>
-
 // Local includes
 
-#include "imageslist.h"
+#include "kpimageslist.h"
 #include "manager.h"
 #include "actionthread.h"
 
@@ -61,13 +57,13 @@ struct ItemsPage::ItemsPagePriv
     {
     }
 
-    ImagesList* list;
+    KPImagesList* list;
 
-    Manager*    mngr;
+    Manager*      mngr;
 };
 
-ItemsPage::ItemsPage(Manager* mngr, KAssistantDialog* dlg)
-    : WizardPage(dlg, i18n("<b>Set Panorama Images</b>")),d(new ItemsPagePriv)
+ItemsPage::ItemsPage(Manager* const mngr, KAssistantDialog* const dlg)
+    : KPWizardPage(dlg, i18n("<b>Set Panorama Images</b>")), d(new ItemsPagePriv)
 {
     d->mngr        = mngr;
     KVBox* vbox    = new KVBox(this);
@@ -84,7 +80,7 @@ ItemsPage::ItemsPage(Manager* mngr, KAssistantDialog* dlg)
                          "the panorama.</p>"
                          "</qt>"));
 
-    d->list = new ImagesList(d->mngr->iface(), vbox);
+    d->list = new KPImagesList(vbox);
     d->list->slotAddImages(d->mngr->itemsList());
 
     setPageWidget(vbox);
