@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2003-10-24
  * Description : Raw converter batch dialog
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2011 by Veaceslav Munteanu <slavuttici at gmail dot com>
+ * Copyright (C) 2006-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2011      by Veaceslav Munteanu <slavuttici at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,7 +44,6 @@ extern "C"
 #include <QFileInfo>
 #include <QGridLayout>
 #include <QPixmap>
-#include <QProgressBar>
 #include <QPushButton>
 #include <QTimer>
 #include <QTreeWidgetItemIterator>
@@ -55,39 +54,35 @@ extern "C"
 #include <kconfig.h>
 #include <kcursor.h>
 #include <kdebug.h>
-#include <khelpmenu.h>
 #include <kiconloader.h>
 #include <kio/renamedialog.h>
+#include <kde_file.h>
 #include <klocale.h>
 #include <kmenu.h>
 #include <kmessagebox.h>
 #include <kpushbutton.h>
 #include <kstandarddirs.h>
-#include <ktoolinvocation.h>
 
 // LibKDcraw includes
 
 #include <libkdcraw/version.h>
 #include <libkdcraw/dcrawsettingswidget.h>
 
-// LibKIPI includes
-
-#include <libkipi/interface.h>
-#include <libkipi/imageinfo.h>
-
 // Local includes
 
 #include "actions.h"
 #include "actionthread.h"
 #include "myimagelist.h"
-#include "imagedialog.h"
+#include "kpimagedialog.h"
 #include "kpaboutdata.h"
-#include "pluginsversion.h"
+#include "kpversion.h"
+#include "kpimageinfo.h"
+#include "kphostsettings.h"
+#include "kpsavesettingswidget.h"
 #include "rawdecodingiface.h"
-#include "savesettingswidget.h"
+#include "kpprogresswidget.h"
 
 using namespace KDcrawIface;
-using namespace KIPIPlugins;
 
 namespace KIPIRawConverterPlugin
 {
@@ -105,49 +100,42 @@ public:
         thread              = 0;
         saveSettingsBox     = 0;
         decodingSettingsBox = 0;
-        about               = 0;
-        iface               = 0;
     }
 
-    bool                 busy;
+    bool                  busy;
 
-    QWidget*             page;
+    QWidget*              page;
 
-    QStringList          fileList;
+    QStringList           fileList;
 
-    QProgressBar*        progressBar;
+    KPProgressWidget*     progressBar;
 
-    MyImageList*         listView;
+    MyImageList*          listView;
 
-    ActionThread*        thread;
+    ActionThread*         thread;
 
-    SaveSettingsWidget*  saveSettingsBox;
+    KPSaveSettingsWidget* saveSettingsBox;
 
-    DcrawSettingsWidget* decodingSettingsBox;
-
-    KPAboutData*         about;
-
-    KIPI::Interface*     iface;
+    DcrawSettingsWidget*  decodingSettingsBox;
 };
 
-BatchDialog::BatchDialog(KIPI::Interface* iface)
-           : KDialog(0), d(new BatchDialogPriv)
+BatchDialog::BatchDialog()
+    : KPToolDialog(0), d(new BatchDialogPriv)
 {
-    d->iface = iface;
-
     setButtons(Help | Default | Apply | Close );
     setDefaultButton(Close);
     setButtonToolTip(Close, i18n("Exit RAW Converter"));
     setCaption(i18n("RAW Image Batch Converter"));
     setModal(false);
+    setMinimumSize(700, 500);
 
-    d->page = new QWidget( this );
-    setMainWidget( d->page );
-    QGridLayout *mainLayout = new QGridLayout(d->page);
+    d->page = new QWidget(this);
+    setMainWidget(d->page);
+    QGridLayout* mainLayout = new QGridLayout(d->page);
 
     //---------------------------------------------
 
-    d->listView = new MyImageList(d->iface, d->page);
+    d->listView = new MyImageList(d->page);
 
     // ---------------------------------------------------------------
 
@@ -156,7 +144,8 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
                                                               DcrawSettingsWidget::POSTPROCESSING |
                                                               DcrawSettingsWidget::BLACKWHITEPOINTS);
     d->decodingSettingsBox->setObjectName("RawSettingsBox Expander");
-    d->saveSettingsBox     = new SaveSettingsWidget(d->page);
+    d->saveSettingsBox     = new KPSaveSettingsWidget(d->page);
+    d->saveSettingsBox->setPromptButtonText("Store it under different name");
 
 #if KDCRAW_VERSION <= 0x000500
     d->decodingSettingsBox->addItem(d->saveSettingsBox, i18n("Save settings"));
@@ -167,7 +156,7 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
                                        QString("savesettings"), false);
 #endif
 
-    d->progressBar = new QProgressBar(d->page);
+    d->progressBar = new KPProgressWidget(d->page);
     d->progressBar->setMaximumHeight( fontMetrics().height()+2 );
     d->progressBar->hide();
 
@@ -182,42 +171,41 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
 #endif
 
     // ---------------------------------------------------------------
-    // About data and help button.
 
-    d->about = new KIPIPlugins::KPAboutData(ki18n("RAW Image Converter"),
-                   0,
-                   KAboutData::License_GPL,
-                   ki18n("A Kipi plugin to batch convert RAW images"),
-                   ki18n("(c) 2003-2005, Renchi Raju\n"
-                         "(c) 2006-2011, Gilles Caulier"));
+    KPAboutData* about = new KPAboutData(ki18n("RAW Image Converter"),
+                             0,
+                             KAboutData::License_GPL,
+                             ki18n("A Kipi plugin to convert RAW images"),
+                             ki18n("(c) 2003-2005, Renchi Raju\n"
+                                   "(c) 2006-2012, Gilles Caulier\n"
+                                   "(c) 2012, Smit Mehta"));
 
-    d->about->addAuthor(ki18n("Renchi Raju"),
-                       ki18n("Author"),
-                             "renchi dot raju at gmail dot com");
+    about->addAuthor(ki18n("Renchi Raju"),
+                     ki18n("Author"),
+                           "renchi dot raju at gmail dot com");
 
-    d->about->addAuthor(ki18n("Gilles Caulier"),
-                       ki18n("Developer and maintainer"),
-                             "caulier dot gilles at gmail dot com");
+    about->addAuthor(ki18n("Gilles Caulier"),
+                     ki18n("Developer and maintainer"),
+                           "caulier dot gilles at gmail dot com");
 
-    disconnect(this, SIGNAL(helpClicked()),
-               this, SLOT(slotHelp()));
+    about->addAuthor(ki18n("Smit Mehta"),
+                     ki18n("Developer"),
+                           "smit dot meh at gmail dot com");
 
-    KHelpMenu* helpMenu = new KHelpMenu(this, d->about, false);
-    helpMenu->menu()->removeAction(helpMenu->menu()->actions().first());
-    QAction* handbook   = new QAction(i18n("Handbook"), this);
-    connect(handbook, SIGNAL(triggered(bool)),
-            this, SLOT(slotHelp()));
-    helpMenu->menu()->insertAction(helpMenu->menu()->actions().first(), handbook);
-    button(Help)->setMenu(helpMenu->menu());
+    about->setHandbookEntry("rawconverter");
+    setAboutData(about);
 
     // ---------------------------------------------------------------
 
-    d->thread = new ActionThread(this, d->iface->hostSetting("WriteMetadataUpdateFiletimeStamp").toBool());
+    d->thread = new ActionThread(this);
 
     // ---------------------------------------------------------------
 
     connect(d->saveSettingsBox, SIGNAL(signalSaveFormatChanged()),
-            this, SLOT(slotSaveFormatChanged()));
+            this, SLOT(slotIdentify()));
+
+    connect(d->saveSettingsBox, SIGNAL(signalConflictButtonChanged(int)),
+            this, SLOT(slotIdentify()));
 
     connect(d->decodingSettingsBox, SIGNAL(signalSixteenBitsImageToggled(bool)),
             d->saveSettingsBox, SLOT(slotPopulateImageFormat(bool)));
@@ -234,15 +222,21 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
     connect(this, SIGNAL(applyClicked()),
             this, SLOT(slotStartStop()));
 
-    connect(d->thread, SIGNAL(starting(KIPIRawConverterPlugin::ActionData)),
+    connect(d->thread, SIGNAL(signalStarting(KIPIRawConverterPlugin::ActionData)),
             this, SLOT(slotAction(KIPIRawConverterPlugin::ActionData)));
 
-    connect(d->thread, SIGNAL(finished(KIPIRawConverterPlugin::ActionData)),
+    connect(d->thread, SIGNAL(signalFinished(KIPIRawConverterPlugin::ActionData)),
             this, SLOT(slotAction(KIPIRawConverterPlugin::ActionData)));
 
+    connect(d->thread, SIGNAL(finished()),
+            this, SLOT(slotThreadFinished()));
+
     connect(d->listView, SIGNAL(signalImageListChanged()),
             this, SLOT(slotIdentify()));
 
+    connect(d->progressBar, SIGNAL(signalProgressCanceled()),
+            this, SLOT(slotStartStop()));
+
     // ---------------------------------------------------------------
 
     busy(false);
@@ -251,15 +245,9 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
 
 BatchDialog::~BatchDialog()
 {
-    delete d->about;
     delete d;
 }
 
-void BatchDialog::slotHelp()
-{
-    KToolInvocation::invokeHelp("rawconverter", "kipi-plugins");
-}
-
 void BatchDialog::slotSixteenBitsImageToggled(bool)
 {
     // Dcraw do not provide a way to set brigness of image in 16 bits color depth.
@@ -352,9 +340,11 @@ void BatchDialog::slotStartStop()
         d->progressBar->setMaximum(d->fileList.count());
         d->progressBar->setValue(0);
         d->progressBar->show();
+        d->progressBar->progressScheduled(i18n("RAW Converter"), true, true);
+        d->progressBar->progressThumbnailChanged(KIcon("rawconverter").pixmap(22));
 
         d->thread->setRawDecodingSettings(d->decodingSettingsBox->settings(), d->saveSettingsBox->fileFormat());
-        processOne();
+        processAll();
     }
     else
     {
@@ -362,7 +352,7 @@ void BatchDialog::slotStartStop()
         d->thread->cancel();
         busy(false);
 
-        d->listView->processed(false);
+        d->listView->cancelProcess();
 
         QTimer::singleShot(500, this, SLOT(slotAborted()));
     }
@@ -372,7 +362,9 @@ void BatchDialog::slotAborted()
 {
     d->progressBar->setValue(0);
     d->progressBar->hide();
+    d->progressBar->progressCompleted();
 }
+
 void BatchDialog::addItems(const KUrl::List& itemList)
 {
     d->listView->slotAddImages(itemList);
@@ -384,28 +376,69 @@ void BatchDialog::slotIdentify() // Set Identity and Target file
 
     switch(d->saveSettingsBox->fileFormat())
     {
-        case SaveSettingsWidget::OUTPUT_JPEG:
+        case KPSaveSettingsWidget::OUTPUT_JPEG:
             ext = ".jpg";
             break;
-        case SaveSettingsWidget::OUTPUT_TIFF:
+        case KPSaveSettingsWidget::OUTPUT_TIFF:
             ext = ".tif";
             break;
-        case SaveSettingsWidget::OUTPUT_PPM:
+        case KPSaveSettingsWidget::OUTPUT_PPM:
             ext = ".ppm";
             break;
-        case SaveSettingsWidget::OUTPUT_PNG:
+        case KPSaveSettingsWidget::OUTPUT_PNG:
             ext = ".png";
             break;
     }
+
     KUrl::List urlList = d->listView->imageUrls(true);
 
     for (KUrl::List::const_iterator  it = urlList.constBegin();
          it != urlList.constEnd(); ++it)
     {
         QFileInfo fi((*it).path());
-        QString dest              = fi.completeBaseName() + ext;
-        MyImageListViewItem* item = dynamic_cast<MyImageListViewItem*>(d->listView->listView()->findItem(*it));
-        if (item) item->setDestFileName(dest);
+
+        if(d->saveSettingsBox->conflictRule() == KPSaveSettingsWidget::OVERWRITE)
+        {
+            QString dest              = fi.completeBaseName() + ext;
+            MyImageListViewItem* item = dynamic_cast<MyImageListViewItem*>(d->listView->listView()->findItem(*it));
+            if (item) item->setDestFileName(dest);
+        }
+
+        else
+        {
+            int i        = 0;
+            QString dest = fi.absolutePath() + QString("/") + fi.completeBaseName() + ext;
+            QFileInfo a(dest);
+
+            bool fileNotFound = (a.exists());
+
+            if (!fileNotFound)
+            {
+                dest = fi.completeBaseName() + ext;
+            }
+
+            else
+            {
+                while(fileNotFound)
+                {
+                    a = QFileInfo(dest);
+                    if (!a.exists())
+                    {
+                        fileNotFound = false;
+                    }
+                    else
+                    {
+                        i++;
+                        dest = fi.absolutePath() + QString("/") + fi.completeBaseName() + QString("_") + QString::number(i) + ext;
+                    }
+                }
+
+                dest = fi.completeBaseName() + QString("_") + QString::number(i) + ext;
+            }
+
+            MyImageListViewItem* item = dynamic_cast<MyImageListViewItem*>(d->listView->listView()->findItem(*it));
+            if (item) item->setDestFileName(dest);
+        }
     }
 
     if (!urlList.empty())
@@ -415,60 +448,21 @@ void BatchDialog::slotIdentify() // Set Identity and Target file
             d->thread->start();
     }
 }
-void BatchDialog::slotSaveFormatChanged()
+
+void BatchDialog::processAll()
 {
-    QString ext;
+    d->thread->processRawFiles(d->listView->imageUrls(true));
 
-    switch(d->saveSettingsBox->fileFormat())
-    {
-        case SaveSettingsWidget::OUTPUT_JPEG:
-            ext = "jpg";
-            break;
-        case SaveSettingsWidget::OUTPUT_TIFF:
-            ext = "tif";
-            break;
-        case SaveSettingsWidget::OUTPUT_PPM:
-            ext = "ppm";
-            break;
-        case SaveSettingsWidget::OUTPUT_PNG:
-            ext = "png";
-            break;
-    }
-
-    QTreeWidgetItemIterator it(d->listView->listView());
-    while (*it)
-    {
-        MyImageListViewItem* lvItem = dynamic_cast<MyImageListViewItem*>(*it);
-        if (lvItem)
-        {
-            if (!lvItem->isDisabled())
-            {
-                QFileInfo fi(lvItem->url().path());
-                QString dest = fi.completeBaseName() + QString(".") + ext;
-                lvItem->setDestFileName(dest);
-            }
-        }
-        ++it;
-    }
-}
-
-void BatchDialog::processOne()
-{
-    if (d->fileList.empty())
-    {
-        busy(false);
-        slotAborted();
-        return;
-    }
-
-    QString file(d->fileList.first());
-    d->fileList.pop_front();
-
-    d->thread->processRawFile(KUrl(file));
     if (!d->thread->isRunning())
         d->thread->start();
 }
 
+void BatchDialog::slotThreadFinished()
+{
+    busy(false);
+    slotAborted();
+}
+
 void BatchDialog::busy(bool busy)
 {
     d->busy = busy;
@@ -477,14 +471,14 @@ void BatchDialog::busy(bool busy)
 
     if (d->busy)
     {
-        setButtonIcon(Apply, KIcon("process-stop"));
-        setButtonText(Apply, i18n("&Abort"));
+        setButtonIcon(Apply,    KIcon("process-stop"));
+        setButtonText(Apply,    i18n("&Abort"));
         setButtonToolTip(Apply, i18n("Abort the current RAW file conversion"));
     }
     else
     {
-        setButtonIcon(Apply, KIcon("system-run"));
-        setButtonText(Apply, i18n("Con&vert"));
+        setButtonIcon(Apply,    KIcon("system-run"));
+        setButtonText(Apply,    i18n("Con&vert"));
         setButtonToolTip(Apply, i18n("Start converting the RAW images using current settings."));
     }
 
@@ -499,64 +493,53 @@ void BatchDialog::processed(const KUrl& url, const QString& tmpFile)
 {
     MyImageListViewItem* item = dynamic_cast<MyImageListViewItem*>(d->listView->listView()->findItem(url));
     if (!item) return;
+
     QString destFile(item->destPath());
 
-    if (d->saveSettingsBox->conflictRule() != SaveSettingsWidget::OVERWRITE)
+    if (d->saveSettingsBox->conflictRule() != KPSaveSettingsWidget::OVERWRITE)
     {
         struct stat statBuf;
         if (::stat(QFile::encodeName(destFile), &statBuf) == 0)
         {
-            KIO::RenameDialog dlg(this, i18n("Save RAW image converted from '%1' as",
-                                  url.fileName()),
-                                  tmpFile, destFile,
-                                  KIO::RenameDialog_Mode(KIO::M_SINGLE | KIO::M_OVERWRITE | KIO::M_SKIP));
-
-            switch (dlg.exec())
-            {
-                case KIO::R_CANCEL:
-                case KIO::R_SKIP:
-                {
-                    destFile.clear();
-                    d->listView->processed(false);
-                    break;
-                }
-                case KIO::R_RENAME:
-                {
-                    destFile = dlg.newDestUrl().path();
-                    break;
-                }
-                default:    // Overwrite.
-                    break;
-            }
+            item->setStatus(QString("Failed to save image"));
         }
     }
 
     if (!destFile.isEmpty())
     {
+        if (KPMetadata::hasSidecar(tmpFile))
+        {
+            if (KDE::rename(KPMetadata::sidecarPath(tmpFile),
+                            KPMetadata::sidecarPath(destFile)) != 0)
+            {
+                item->setStatus(QString("Failed to move sidecar"));
+            }
+        }
+
         if (::rename(QFile::encodeName(tmpFile), QFile::encodeName(destFile)) != 0)
         {
-            KMessageBox::error(this, i18n("Failed to save image %1", destFile));
-            d->listView->processed(false);
+            item->setStatus(QString("Failed to save image."));
+            d->listView->processed(url, false);
         }
         else
         {
             item->setDestFileName(QFileInfo(destFile).fileName());
-            d->listView->processed(true);
+            d->listView->processed(url, true);
+            item->setStatus(QString("Success"));
 
             // Assign Kipi host attributes from original RAW image.
 
-            KIPI::ImageInfo orgInfo = d->iface->info(url);
-            KIPI::ImageInfo newInfo = d->iface->info(KUrl(destFile));
-            newInfo.cloneData(orgInfo);
+            KPImageInfo info(url);
+            info.cloneData(KUrl(destFile));
         }
     }
 
     d->progressBar->setValue(d->progressBar->value()+1);
 }
 
-void BatchDialog::processingFailed(const KUrl& /*url*/)
+void BatchDialog::processingFailed(const KUrl& url)
 {
-    d->listView->processed(false);
+    d->listView->processed(url, false);
     d->progressBar->setValue(d->progressBar->value()+1);
 }
 
@@ -574,11 +557,12 @@ void BatchDialog::slotAction(const KIPIRawConverterPlugin::ActionData& ad)
             {
                 busy(true);
                 d->listView->processing(ad.fileUrl);
+                d->progressBar->progressStatusChanged(i18n("Processing %1", ad.fileUrl.fileName()));
                 break;
             }
             default:
             {
-                kWarning() << "KIPIRawConverterPlugin: Unknown action";
+                kWarning() << "Unknown action";
                 break;
             }
         }
@@ -594,12 +578,11 @@ void BatchDialog::slotAction(const KIPIRawConverterPlugin::ActionData& ad)
                 case(PROCESS):
                 {
                     processingFailed(ad.fileUrl);
-                    processOne();
                     break;
                 }
                 default:
                 {
-                    kWarning() << "KIPIRawConverterPlugin: Unknown action";
+                    kWarning() << "Unknown action";
                     break;
                 }
             }
@@ -620,12 +603,11 @@ void BatchDialog::slotAction(const KIPIRawConverterPlugin::ActionData& ad)
                 case(PROCESS):
                 {
                     processed(ad.fileUrl, ad.destPath);
-                    processOne();
                     break;
                 }
                 default:
                 {
-                    kWarning() << "KIPIRawConverterPlugin: Unknown action";
+                    kWarning() << "Unknown action";
                     break;
                 }
             }
