@@ -1,13 +1,13 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2003-10-22
  * Description : Raw converter single dialog
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -51,15 +51,14 @@ extern "C"
 #include <kconfig.h>
 #include <kcursor.h>
 #include <kdebug.h>
-#include <khelpmenu.h>
 #include <kiconloader.h>
 #include <kio/renamedialog.h>
+#include <kde_file.h>
 #include <klocale.h>
 #include <kmenu.h>
 #include <kmessagebox.h>
 #include <kpushbutton.h>
 #include <kstandarddirs.h>
-#include <ktoolinvocation.h>
 
 // LibKDcraw includes
 
@@ -69,20 +68,20 @@ extern "C"
 // LibKIPI includes
 
 #include <libkipi/interface.h>
-#include <libkipi/imageinfo.h>
+#include <libkipi/pluginloader.h>
 
 // Local includes
 
+#include "kpaboutdata.h"
+#include "kpversion.h"
+#include "kpimageinfo.h"
+#include "kppreviewmanager.h"
+#include "kpsavesettingswidget.h"
+#include "rawdecodingiface.h"
 #include "actions.h"
 #include "actionthread.h"
-#include "kpaboutdata.h"
-#include "pluginsversion.h"
-#include "previewmanager.h"
-#include "rawdecodingiface.h"
-#include "savesettingswidget.h"
 
 using namespace KDcrawIface;
-using namespace KIPIPlugins;
 
 namespace KIPIRawConverterPlugin
 {
@@ -97,31 +96,32 @@ public:
         thread              = 0;
         saveSettingsBox     = 0;
         decodingSettingsBox = 0;
-        about               = 0;
         iface               = 0;
+        PluginLoader* pl    = PluginLoader::instance();
+        if (pl)
+        {
+            iface = pl->interface();
+        }
     }
 
-    QString              inputFileName;
+    QString               inputFileName;
 
-    KUrl                 inputFile;
+    KUrl                  inputFile;
 
-    PreviewManager*      previewWidget;
+    KPPreviewManager*     previewWidget;
 
-    ActionThread*        thread;
+    ActionThread*         thread;
 
-    SaveSettingsWidget*  saveSettingsBox;
+    KPSaveSettingsWidget* saveSettingsBox;
 
-    DcrawSettingsWidget* decodingSettingsBox;
+    DcrawSettingsWidget*  decodingSettingsBox;
 
-    KPAboutData*         about;
-
-    KIPI::Interface*     iface;
+    Interface*            iface;
 };
 
-SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
-            : KDialog(0), d(new SingleDialogPriv)
+SingleDialog::SingleDialog(const QString& file)
+    : KPToolDialog(0), d(new SingleDialogPriv)
 {
-    d->iface = iface;
     setButtons(Help | Default | User1 | User2 | User3 | Close);
     setDefaultButton(Close);
     setButtonText(User1, i18n("&Preview"));
@@ -130,11 +130,11 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
     setCaption(i18n("RAW Image Converter"));
     setModal(false);
 
-    QWidget* page = new QWidget( this );
+    QWidget* page           = new QWidget( this );
     setMainWidget( page );
     QGridLayout* mainLayout = new QGridLayout(page);
 
-    d->previewWidget        = new PreviewManager(page);
+    d->previewWidget        = new KPPreviewManager(page);
 
     // ---------------------------------------------------------------
 
@@ -142,7 +142,7 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
                                                             DcrawSettingsWidget::COLORSPACE     |
                                                             DcrawSettingsWidget::POSTPROCESSING |
                                                             DcrawSettingsWidget::BLACKWHITEPOINTS);
-    d->saveSettingsBox      = new SaveSettingsWidget(d->decodingSettingsBox);
+    d->saveSettingsBox      = new KPSaveSettingsWidget(d->decodingSettingsBox);
 
 #if KDCRAW_VERSION <= 0x000500
     d->decodingSettingsBox->addItem(d->saveSettingsBox, i18n("Save settings"));
@@ -161,33 +161,29 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
 #endif
 
     // ---------------------------------------------------------------
-    // About data and help button.
 
-    d->about = new KIPIPlugins::KPAboutData(ki18n("RAW Image Converter"),
-                   0,
-                   KAboutData::License_GPL,
-                   ki18n("A Kipi plugin to convert RAW images"),
-                   ki18n("(c) 2003-2005, Renchi Raju\n"
-                         "(c) 2006-2011, Gilles Caulier"));
+    KPAboutData* about = new KPAboutData(ki18n("RAW Image Converter"),
+                             0,
+                             KAboutData::License_GPL,
+                             ki18n("A Kipi plugin to convert RAW images"),
+                             ki18n("(c) 2003-2005, Renchi Raju\n"
+                                   "(c) 2006-2012, Gilles Caulier\n"
+                                   "(c) 2012, Smit Mehta"));
 
-    d->about->addAuthor(ki18n("Renchi Raju"),
-                       ki18n("Author"),
-                             "renchi dot raju at gmail dot com");
+    about->addAuthor(ki18n("Renchi Raju"),
+                     ki18n("Author"),
+                           "renchi dot raju at gmail dot com");
 
-    d->about->addAuthor(ki18n("Gilles Caulier"),
-                       ki18n("Developer and maintainer"),
-                             "caulier dot gilles at gmail dot com");
+    about->addAuthor(ki18n("Gilles Caulier"),
+                     ki18n("Developer and maintainer"),
+                           "caulier dot gilles at gmail dot com");
 
-    disconnect(this, SIGNAL(helpClicked()),
-               this, SLOT(slotHelp()));
+    about->addAuthor(ki18n("Smit Mehta"),
+                     ki18n("Developer"),
+                           "smit dot meh at gmail dot com");
 
-    KHelpMenu* helpMenu = new KHelpMenu(this, d->about, false);
-    helpMenu->menu()->removeAction(helpMenu->menu()->actions().first());
-    QAction* handbook   = new QAction(i18n("Handbook"), this);
-    connect(handbook, SIGNAL(triggered(bool)),
-            this, SLOT(slotHelp()));
-    helpMenu->menu()->insertAction(helpMenu->menu()->actions().first(), handbook);
-    button(Help)->setMenu(helpMenu->menu());
+    about->setHandbookEntry("rawconverter");
+    setAboutData(about);
 
     // ---------------------------------------------------------------
 
@@ -202,7 +198,9 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
 
     setButtonToolTip(Close, i18n("Exit RAW Converter"));
 
-    d->thread = new ActionThread(this, d->iface->hostSetting("WriteMetadataUpdateFiletimeStamp").toBool());
+    // ---------------------------------------------------------------
+
+    d->thread = new ActionThread(this);
 
     // ---------------------------------------------------------------
 
@@ -242,7 +240,6 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
 
 SingleDialog::~SingleDialog()
 {
-    delete d->about;
     delete d->thread;
     delete d;
 }
@@ -254,11 +251,6 @@ void SingleDialog::setFile(const QString& file)
     QTimer::singleShot(0, this, SLOT(slotIdentify()));
 }
 
-void SingleDialog::slotHelp()
-{
-    KToolInvocation::invokeHelp("rawconverter", "kipi-plugins");
-}
-
 void SingleDialog::slotSixteenBitsImageToggled(bool)
 {
     // Dcraw do not provide a way to set brigness of image in 16 bits color depth.
@@ -316,7 +308,7 @@ void SingleDialog::saveSettings()
 // 'Preview' dialog button.
 void SingleDialog::slotUser1()
 {
-    d->thread->setRawDecodingSettings(d->decodingSettingsBox->settings(), SaveSettingsWidget::OUTPUT_PNG);
+    d->thread->setRawDecodingSettings(d->decodingSettingsBox->settings(), KPSaveSettingsWidget::OUTPUT_PNG);
     d->thread->processHalfRawFile(KUrl(d->inputFile));
     if (!d->thread->isRunning())
         d->thread->start();
@@ -339,7 +331,7 @@ void SingleDialog::slotUser3()
 
 void SingleDialog::slotIdentify()
 {
-    if (!d->iface->hasFeature(KIPI::HostSupportsThumbnails))
+    if (!d->iface->hasFeature(HostSupportsThumbnails))
     {
         d->thread->thumbRawFile(KUrl(d->inputFile));
     }
@@ -411,16 +403,16 @@ void SingleDialog::processed(const KUrl& url, const QString& tmpFile)
 
     switch(d->saveSettingsBox->fileFormat())
     {
-        case SaveSettingsWidget::OUTPUT_JPEG:
+        case KPSaveSettingsWidget::OUTPUT_JPEG:
             ext = "jpg";
             break;
-        case SaveSettingsWidget::OUTPUT_TIFF:
+        case KPSaveSettingsWidget::OUTPUT_TIFF:
             ext = "tif";
             break;
-        case SaveSettingsWidget::OUTPUT_PPM:
+        case KPSaveSettingsWidget::OUTPUT_PPM:
             ext = "ppm";
             break;
-        case SaveSettingsWidget::OUTPUT_PNG:
+        case KPSaveSettingsWidget::OUTPUT_PNG:
             ext = "png";
             break;
     }
@@ -429,7 +421,7 @@ void SingleDialog::processed(const KUrl& url, const QString& tmpFile)
     QFileInfo fi(d->inputFile.path());
     QString destFile = fi.absolutePath() + QString("/") + fi.completeBaseName() + QString(".") + ext;
 
-    if (d->saveSettingsBox->conflictRule() != SaveSettingsWidget::OVERWRITE)
+    if (d->saveSettingsBox->conflictRule() != KPSaveSettingsWidget::OVERWRITE)
     {
         struct stat statBuf;
         if (::stat(QFile::encodeName(destFile), &statBuf) == 0)
@@ -459,6 +451,15 @@ void SingleDialog::processed(const KUrl& url, const QString& tmpFile)
 
     if (!destFile.isEmpty())
     {
+        if (KPMetadata::hasSidecar(tmpFile))
+        {
+            if (KDE::rename(KPMetadata::sidecarPath(tmpFile),
+                            KPMetadata::sidecarPath(destFile)) != 0)
+            {
+                KMessageBox::information(this, i18n("Failed to save sidecar file for image %1...", destFile));
+            }
+        }
+
         if (::rename(QFile::encodeName(tmpFile), QFile::encodeName(destFile)) != 0)
         {
             KMessageBox::error(this, i18n("Failed to save image %1", destFile));
@@ -467,9 +468,8 @@ void SingleDialog::processed(const KUrl& url, const QString& tmpFile)
         {
             // Assign Kipi host attributes from original RAW image.
 
-            KIPI::ImageInfo orgInfo = d->iface->info(url);
-            KIPI::ImageInfo newInfo = d->iface->info(KUrl(destFile));
-            newInfo.cloneData(orgInfo);
+            KPImageInfo info(url);
+            info.cloneData(KUrl(destFile));
         }
     }
 }
@@ -505,7 +505,7 @@ void SingleDialog::slotAction(const KIPIRawConverterPlugin::ActionData& ad)
             }
             default:
             {
-                kWarning() << "KIPIRawConverterPlugin: Unknown action";
+                kWarning() << "Unknown action";
                 break;
             }
         }
@@ -533,7 +533,7 @@ void SingleDialog::slotAction(const KIPIRawConverterPlugin::ActionData& ad)
                 }
                 default:
                 {
-                    kWarning() << "KIPIRawConverterPlugin: Unknown action";
+                    kWarning() << "Unknown action";
                     break;
                 }
             }
@@ -569,7 +569,7 @@ void SingleDialog::slotAction(const KIPIRawConverterPlugin::ActionData& ad)
                 }
                 default:
                 {
-                    kWarning() << "KIPIRawConverterPlugin: Unknown action";
+                    kWarning() << "Unknown action";
                     break;
                 }
             }
