@@ -1,14 +1,14 @@
 /* ============================================================
  *
  * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * http://www.digikam.org
  *
  * Date        : 2005-17-06
  * Description : a kipi plugin to import/export images to/from
  *                SmugMug web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2012 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -30,7 +30,6 @@
 #include <QFileInfo>
 #include <QSpinBox>
 #include <QCheckBox>
-#include <QProgressBar>
 #include <QGroupBox>
 #include <QCloseEvent>
 
@@ -48,10 +47,6 @@
 #include <kpassworddialog.h>
 #include <ktoolinvocation.h>
 
-// LibKExiv2 includes
-
-#include <libkexiv2/kexiv2.h>
-
 // LibKDcraw includes
 
 #include <libkdcraw/version.h>
@@ -64,9 +59,12 @@
 
 // Local includes
 
-#include "imageslist.h"
+#include "kpimageslist.h"
+#include "kpmetadata.h"
 #include "kpaboutdata.h"
-#include "pluginsversion.h"
+#include "kpimageinfo.h"
+#include "kpversion.h"
+#include "kpprogresswidget.h"
 #include "smugitem.h"
 #include "smugtalker.h"
 #include "smugwidget.h"
@@ -75,17 +73,15 @@
 namespace KIPISmugPlugin
 {
 
-SmugWindow::SmugWindow(KIPI::Interface* interface, const QString& tmpFolder,
-                       bool import, QWidget* /*parent*/)
-          : KDialog(0)
+SmugWindow::SmugWindow(const QString& tmpFolder, bool import, QWidget* const /*parent*/)
+    : KPToolDialog(0)
 {
     m_tmpPath.clear();
     m_tmpDir      = tmpFolder;
-    m_interface   = interface;
     m_import      = import;
     m_imagesCount = 0;
     m_imagesTotal = 0;
-    m_widget      = new SmugWidget(this, interface, import);
+    m_widget      = new SmugWidget(this, iface(), import);
 
     setMainWidget(m_widget);
     setWindowIcon(KIcon("smugmug"));
@@ -128,27 +124,19 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString& tmpFolder,
 
     // ------------------------------------------------------------------------
 
-    m_about = new KIPIPlugins::KPAboutData(ki18n("Smug Import/Export"), 0,
-                      KAboutData::License_GPL,
-                      ki18n("A Kipi plugin to import/export image collections "
-                            "from/to the SmugMug web service."),
-                      ki18n("(c) 2005-2008, Vardhman Jain\n"
-                            "(c) 2008-2009, Gilles Caulier\n"
-                            "(c) 2008-2009, Luka Renko"));
+    KPAboutData* about = new KPAboutData(ki18n("Smug Import/Export"), 0,
+                             KAboutData::License_GPL,
+                             ki18n("A Kipi plugin to import/export image collections "
+                                   "from/to the SmugMug web service."),
+                             ki18n("(c) 2005-2008, Vardhman Jain\n"
+                                   "(c) 2008-2012, Gilles Caulier\n"
+                                   "(c) 2008-2009, Luka Renko"));
 
-    m_about->addAuthor(ki18n("Luka Renko"), ki18n("Author and maintainer"),
-                       "lure at kubuntu dot org");
+    about->addAuthor(ki18n("Luka Renko"), ki18n("Author and maintainer"),
+                     "lure at kubuntu dot org");
 
-    disconnect(this, SIGNAL(helpClicked()),
-               this, SLOT(slotHelp()) );
-
-    KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
-    helpMenu->menu()->removeAction(helpMenu->menu()->actions().first());
-    QAction *handbook   = new QAction(i18n("Handbook"), this);
-    connect(handbook, SIGNAL(triggered(bool)),
-            this, SLOT(slotHelp()));
-    helpMenu->menu()->insertAction(helpMenu->menu()->actions().first(), handbook);
-    button(Help)->setMenu(helpMenu->menu());
+    about->setHandbookEntry("smug");
+    setAboutData(about);
 
     // ------------------------------------------------------------------------
 
@@ -193,6 +181,7 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString& tmpFolder,
 
     connect(m_talker, SIGNAL(signalListPhotosDone(int,QString,QList<SmugPhoto>)),
             this, SLOT(slotListPhotosDone(int,QString,QList<SmugPhoto>)));
+
     connect(m_talker, SIGNAL(signalListAlbumTmplDone(int,QString,QList<SmugAlbumTmpl>)),
             this, SLOT(slotListAlbumTmplDone(int,QString,QList<SmugAlbumTmpl>)));
 
@@ -202,6 +191,9 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString& tmpFolder,
     connect(m_talker, SIGNAL(signalListSubCategoriesDone(int,QString,QList<SmugCategory>)),
             this, SLOT(slotListSubCategoriesDone(int,QString,QList<SmugCategory>)));
 
+    connect(m_widget->progressBar(), SIGNAL(signalProgressCanceled()),
+            this, SLOT(slotStopAndCloseProgressBar()));
+
     // ------------------------------------------------------------------------
 
     readSettings();
@@ -235,15 +227,9 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString& tmpFolder,
 SmugWindow::~SmugWindow()
 {
     delete m_talker;
-    delete m_about;
 }
 
-void SmugWindow::slotHelp()
-{
-    KToolInvocation::invokeHelp("smug", "kipi-plugins");
-}
-
-void SmugWindow::closeEvent(QCloseEvent *e)
+void SmugWindow::closeEvent(QCloseEvent* e)
 {
     if (!e) return;
 
@@ -255,6 +241,17 @@ void SmugWindow::closeEvent(QCloseEvent *e)
     e->accept();
 }
 
+void SmugWindow::slotStopAndCloseProgressBar()
+{
+    m_talker->cancel();
+    m_transferQueue.clear();
+    m_widget->m_imgList->cancelProcess();
+    writeSettings();
+    m_widget->imagesList()->listView()->clear();
+    m_widget->progressBar()->progressCompleted();
+    done(Close);
+}
+
 void SmugWindow::slotButtonClicked(int button)
 {
     switch (button)
@@ -264,14 +261,16 @@ void SmugWindow::slotButtonClicked(int button)
             {
                 writeSettings();
                 m_widget->imagesList()->listView()->clear();
+                m_widget->progressBar()->progressCompleted();
                 done(Close);
             }
             else // cancel login/transfer
             {
                 m_talker->cancel();
                 m_transferQueue.clear();
-                m_widget->m_imgList->processed(false);
+                m_widget->m_imgList->cancelProcess();
                 m_widget->progressBar()->hide();
+                m_widget->progressBar()->progressCompleted();
             }
             break;
         case User1:
@@ -359,7 +358,7 @@ void SmugWindow::writeSettings()
 
 void SmugWindow::slotLoginProgress(int step, int maxStep, const QString &label)
 {
-    QProgressBar* progressBar = m_widget->progressBar();
+    KPProgressWidget* progressBar = m_widget->progressBar();
 
     if (!label.isEmpty())
         progressBar->setFormat(label);
@@ -654,6 +653,8 @@ void SmugWindow::slotStartTransfer()
         m_widget->progressBar()->setMaximum(0);
         m_widget->progressBar()->setValue(0);
         m_widget->progressBar()->show();
+        m_widget->progressBar()->progressScheduled(i18n("Smug Import"), true, true);
+        m_widget->progressBar()->progressThumbnailChanged(KIcon("kipi").pixmap(22, 22));
 
         // list photos of the album, then start download
         m_talker->listPhotos(m_widget->m_albumsCoB->itemData(
@@ -678,6 +679,8 @@ void SmugWindow::slotStartTransfer()
         m_widget->progressBar()->setMaximum(m_imagesTotal);
         m_widget->progressBar()->setValue(0);
         m_widget->progressBar()->show();
+        m_widget->progressBar()->progressScheduled(i18n("Smug Export"), true, true);
+        m_widget->progressBar()->progressThumbnailChanged(KIcon("kipi").pixmap(22, 22));
 
         kDebug() << "m_currentAlbumID" << m_currentAlbumID;
         uploadNextPhoto();
@@ -718,13 +721,13 @@ bool SmugWindow::prepareImageForUpload(const QString& imgPath, bool isRAW)
     kDebug() << "Saving to temp file: " << m_tmpPath;
     image.save(m_tmpPath, "JPEG", m_widget->m_imageQualitySpB->value());
 
-    // copy meta data to temporary image
-    KExiv2Iface::KExiv2 exiv2Iface;
-    if (exiv2Iface.load(imgPath))
+    // copy meta-data to temporary image
+    KPMetadata meta;
+    if (meta.load(imgPath))
     {
-        exiv2Iface.setImageDimensions(image.size());
-        exiv2Iface.setImageProgramId("Kipi-plugins", kipiplugins_version);
-        exiv2Iface.save(m_tmpPath);
+        meta.setImageDimensions(image.size());
+        meta.setImageProgramId("Kipi-plugins", kipiplugins_version);
+        meta.save(m_tmpPath);
     }
 
     return true;
@@ -735,23 +738,22 @@ void SmugWindow::uploadNextPhoto()
     if (m_transferQueue.isEmpty())
     {
         m_widget->progressBar()->hide();
+        m_widget->progressBar()->progressCompleted();
         return;
     }
 
     m_widget->m_imgList->processing(m_transferQueue.first());
 
     QString imgPath = m_transferQueue.first().path();
-    KIPI::ImageInfo info(m_interface->info(imgPath));
+    KPImageInfo info(imgPath);
 
     m_widget->progressBar()->setMaximum(m_imagesTotal);
     m_widget->progressBar()->setValue(m_imagesCount);
 
-    // check if we have to RAW file -> use preview image then
-    QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-    QFileInfo fileInfo(imgPath);
-    bool isRAW = rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper());
     bool res;
 
+    // check if we have to RAW file -> use preview image then
+    bool isRAW = KPMetadata::isRawFile(imgPath);
     if (isRAW || m_widget->m_resizeChB->isChecked())
     {
         if (!prepareImageForUpload(imgPath, isRAW))
@@ -783,7 +785,7 @@ void SmugWindow::slotAddPhotoDone(int errCode, const QString& errMsg)
         m_tmpPath.clear();
     }
 
-    m_widget->m_imgList->processed(errCode == 0);
+    m_widget->m_imgList->processed(m_transferQueue.first(), (errCode == 0));
 
     if (errCode == 0)
     {
@@ -798,6 +800,7 @@ void SmugWindow::slotAddPhotoDone(int errCode, const QString& errMsg)
                          != KMessageBox::Continue)
         {
             m_widget->progressBar()->hide();
+            m_widget->progressBar()->progressCompleted();
             m_transferQueue.clear();
             return;
         }
@@ -811,6 +814,7 @@ void SmugWindow::downloadNextPhoto()
     if (m_transferQueue.isEmpty())
     {
         m_widget->progressBar()->hide();
+        m_widget->progressBar()->progressCompleted();
         return;
     }
 
@@ -857,6 +861,7 @@ void SmugWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
             {
                 m_transferQueue.clear();
                 m_widget->progressBar()->hide();
+                m_widget->progressBar()->progressCompleted();
                 return;
             }
         }
@@ -870,6 +875,7 @@ void SmugWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
         {
             m_transferQueue.clear();
             m_widget->progressBar()->hide();
+            m_widget->progressBar()->progressCompleted();
             return;
         }
     }
