@@ -7,7 +7,7 @@
  * @date   2008-03-14
  * @brief  A widget to host settings as expander box
  *
- * @author Copyright (C) 2008-2011 by Gilles Caulier
+ * @author Copyright (C) 2008-2012 by Gilles Caulier
  *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
  * @author Copyright (C) 2008-2011 by Marcel Wiesweg
  *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
@@ -254,9 +254,6 @@ public:
     virtual void readSettings(KConfigGroup& group);
     virtual void writeSettings(KConfigGroup& group);
 
-    KDE_DEPRECATED void readSettings();
-    KDE_DEPRECATED void writeSettings();
-
 Q_SIGNALS:
 
     void signalItemExpanded(int index, bool b);
